
package org.apache.directory.server.schema.bootstrap;


import java.util.ArrayList;
import javax.naming.NamingException;
import org.apache.directory.shared.ldap.schema.ObjectClassTypeEnum;
import org.apache.directory.server.schema.registries.*;



public class NisObjectClassProducer extends AbstractBootstrapProducer
{

    public NisObjectClassProducer()
    {
        super( ProducerTypeEnum.OBJECT_CLASS_PRODUCER );
    }


            

    
    public void produce( Registries registries, ProducerCallback cb )
        throws NamingException
    {
        ArrayList<String> array = new ArrayList<String>();
        BootstrapObjectClass objectClass;

        
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.0 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.0", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of an account with POSIX attributes" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "uid" );
        array.add( "uidNumber" );
        array.add( "gidNumber" );
        array.add( "homeDirectory" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "userPassword" );
        array.add( "loginShell" );
        array.add( "gecos" );
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "posixAccount" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.0", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.1 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.1", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Additional attributes for shadow passwords" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "uid" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "userPassword" );
        array.add( "shadowLastChange" );
        array.add( "shadowMin" );
        array.add( "shadowMax" );
        array.add( "shadowWarning" );
        array.add( "shadowInactive" );
        array.add( "shadowExpire" );
        array.add( "shadowFlag" );
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "shadowAccount" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.1", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.2 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.2", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of a group of accounts" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "gidNumber" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "userPassword" );
        array.add( "memberUid" );
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "posixGroup" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.2", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.3 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.3", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction an Internet Protocol service" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "ipServicePort" );
        array.add( "ipServiceProtocol" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "ipService" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.3", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.4 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.4", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of an IP protocol" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "ipProtocolNumber" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "ipProtocol" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.4", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.5 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.5", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of an ONC/RPC binding" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "oncRpcNumber" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "oncRpc" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.5", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.6 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.6", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of a host, an IP device" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "ipHostNumber" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "l" );
        array.add( "description" );
        array.add( "manager" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "ipHost" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.6", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.7 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.7", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of an IP network" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "ipNetworkNumber" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "ipNetmaskNumber" );
        array.add( "l" );
        array.add( "description" );
        array.add( "manager" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "ipNetwork" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.7", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.8 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.8", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "Abstraction of a netgroup" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "nisNetgroupTriple" );
        array.add( "memberNisNetgroup" );
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "nisNetgroup" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.8", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.9 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.9", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "A generic abstraction of a NIS map" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "nisMapName" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "nisMap" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.9", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.10 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.10", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "An entry in a NIS map" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.STRUCTURAL );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        array.add( "cn" );
        array.add( "nisMapEntry" );
        array.add( "nisMapName" );
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "description" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "nisObject" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.10", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.11 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.11", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "A device with a MAC address" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "macAddress" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "ieee802Device" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.11", objectClass );

 
        // --------------------------------------------------------------------
        // ObjectClass 1.3.6.1.1.1.2.12 
        // --------------------------------------------------------------------

        objectClass = newObjectClass( "1.3.6.1.1.1.2.12", registries );
        objectClass.setObsolete( false );

        objectClass.setDescription( "A device with boot parameters" );
        // set the objectclass type
        objectClass.setType( ObjectClassTypeEnum.AUXILIARY );
        
        // set superior objectClasses
        array.clear();
        array.add( "top" );
        objectClass.setSuperClassIds( array.toArray( EMPTY ) );
        
        // set must list
        array.clear();
        objectClass.setMustListIds( array.toArray( EMPTY ) );
        
        // set may list
        array.clear();
        array.add( "bootFile" );
        array.add( "bootParameter" );
        objectClass.setMayListIds( array.toArray( EMPTY ) );
        
        // set names
        array.clear();
        array.add( "bootableDevice" );
        objectClass.setNames( array.toArray( EMPTY ) );
        cb.schemaObjectProduced( this, "1.3.6.1.1.1.2.12", objectClass );

    }
}
